import { RouteRecordRaw } from 'vue-router';

export const dynamicRoutes: Array<RouteRecordRaw> = [
    {
        path: '/',
        name: '/',
        component: () => import('/@/layout/index.vue'),
        redirect: '/home',
        meta: {
            isKeepAlive: false
        },
        children: [
            {
                path: '/home',
                name: 'home',
                component: () => import('/@/views/newHome/index.vue'),
                meta: {
                    title: '首页',
                    isLink: '',
                    isHide: false,
                    isKeepAlive: true,
                    isAffix: true,
                    isIframe: false,
                    roles: ['admin', 'common'],
                    icon: 'iconfont icon-shouye'
                }
            }
        ]
    }
];

export const notFoundAndNoPower = [
    {
        path: '/:path(.*)*',
        name: 'notFound',
        component: () => import('/@/views/error/404.vue'),
        meta: {
            title: 'message.staticRoutes.notFound',
            isHide: true
        }
    },
    {
        path: '/401',
        name: 'noPower',
        component: () => import('/@/views/error/401.vue'),
        meta: {
            title: 'message.staticRoutes.noPower',
            isHide: true
        }
    }
];

export const staticRoutes: Array<RouteRecordRaw> = [
    {
        path: '/',
        name: '/',
        component: () => import('/@/layout/index.vue'),
        meta: {
            title: '布局界面'
        },
        children: [
            // 请不要往这里 `children` 中添加内容，此内容为了防止 No match found for location with path "xxx" 问题
            ...notFoundAndNoPower
        ]
    },
    {
        path: '/login',
        name: 'login',
        component: () => import('/@/views/loginPage/loginPage.vue'),
        meta: {
            title: '登录'
        }
    },
    {
        path: '/newMenu',
        name: 'newMenu',
        component: () => import('/@/views/newHome/index.vue'),
        meta: {
            title: '首页',
            isKeepAlive: false
        }
    },
    {
        path: '/warningScreen',
        name: 'warningScreen',
        component: () => import('/@/views/riskWarningSys/warningBigScreen/index.vue'),
        meta: {
            title: '预警预报'
        }
    },
    {
        path: '/inspectFullScreen',
        name: 'inspectFullScreen',
        component: () => import('/@/views/intellectInspect/inspectIndex/components/fullScreen.vue'),
        meta: {
            title: '巡检首页全屏'
        }
    },
    {
        path: '/msgDetail',
        name: 'msgDetail',
        component: () => import('/@/views/riskWarningSys/warningBigScreen/indexs/msgDetail.vue'),
        meta: {
            title: 'spi报告详情'
        }
    },
    {
        path: '/securities',
        name: 'securities',
        component: () => import('/@/views/facilityManagement/securities/index.vue'),
        meta: {
            title: '安全物资与设备'
        }
    },
    {
        path: '/dhzy',
        name: 'dhzy',
        component: () => import('/@/views/newSpecialWorkSystem/workTicket/zysq/index.vue'),
        meta: {
            title: '作业申请'
        }
    },
    {
        path: '/wdsq1',
        name: 'wdsq1',
        component: () => import('/@/views/newSpecialWorkSystem/workTicket/wdsq/index.vue'),
        meta: {
            title: '我的申请'
        }
    },
    {
        path: '/sqjl1',
        name: 'sqjl1',
        component: () => import('/@/views/newSpecialWorkSystem/workTicket/sqjl/index.vue'),
        meta: {
            title: '申请记录'
        }
    },
    {
        path: '/sbtj',
        name: 'sbtj',
        component: () => import('/@/views/newSpecialWorkSystem/workTicket/sbtj/index.vue'),
        meta: {
            title: '申报统计'
        }
    },
    {
        path: '/aqy',
        name: 'aqy',
        component: () => import('/@/views/newSpecialWorkSystem/workerManage/aqyBase/index.vue'),
        meta: {
            title: '安全员管理'
        }
    }
];
